/// <reference path="vendor/gc.spread.sheets.d.ts" />
/// <reference path="Util.ts" />
onload = function () {
    var spread = new spreadNS.Workbook(_getElementFromId('ss'));
    spread.suspendPaint();
    // add 2 Sheets
    spread.setSheetCount(2);
    //set Sheets Name
    var dataSheet = spread.getSheet(0);
    var chartSheet = spread.getSheet(1);
    dataSheet.name("BitCoin Volatility Index");
    chartSheet.name("Error Bar Chart");
    // set dataSource into Sheet1
    setDataSpreadSheet(dataSheet, getVolatilityIndexData(), 1, 1);
    //format the BVolIndex column
    dataSheet.getRange(2, 3, 30, 1).formatter("#,##0.00%");
    //add chart to Sheet2
    addErrorBarChart(chartSheet);
    spread.setActiveSheetIndex(1);
    spread.resumePaint();
};
function addErrorBarChart(sheet) {
    var seriesItem = {
        xValues: "'BitCoin Volatility Index'!$B3:$B33",
        yValues: "'BitCoin Volatility Index'!$E3:$E33",
        name: "'BitCoin Volatility Index'!$E2"
    };
    var chart = addChart(sheet, "ErrorBar", "lineMarkers", { x: 50, y: 50, width: 900, height: 400 }, seriesItem);
    setAxisMinMax(chart, 9000, 11000);
    setChartTitle(chart, "BitCoin Volatility");
    setAreaBorder(chart);
    setErrorBars(chart, 0, 3, 1.0);
    setLegendPosition(chart);
    setLegendFont(chart);
    setDisplayUnit(chart);
    setHoverStyleAnimation(chart);
}
//set error bars
function setErrorBars(chart, seriesIndex, valueType, value) {
    var series = chart.series().get(seriesIndex);
    series.errorBars = {
        vertical: {
            valueType: valueType,
            value: value
        }
    };
    chart.series().set(0, series);
}
// set legend fonts
function setLegendFont(chart) {
    var legend = chart.legend();
    legend.color = "green";
    legend.fontSize = 10;
    legend.fontFamily = "Consolas";
    chart.legend(legend);
}
// set display unit
function setDisplayUnit(chart) {
    var axis = chart.axes();
    if (!axis.primaryValue.displayUnit) {
        axis.primaryValue.displayUnit = {
            unit: chartNS["DisplayUnit"]["hundreds"],
            visible: true
        };
    }
    chart.axes(axis);
}
//set legend position
function setLegendPosition(chart) {
    var legend = chart.legend();
    legend.position = chartNS.LegendPosition["topRight"];
    chart.legend(legend);
}
//set Chart AreaBorder
function setAreaBorder(chart) {
    var _area = chart.chartArea();
    _area.border = {
        width: 2,
        dashStyle: 2,
        color: 'blue'
    };
    chart.chartArea(_area);
}
//set hover styles and animation
function setHoverStyleAnimation(chart) {
    //style series
    var hoverStyle = chart.hoverStyle();
    if (!hoverStyle) {
        hoverStyle = {
            color: 'coral',
            transparency: 0.6,
            borderStyle: {
                transparency: 0.5,
                color: "red",
                width: 3
            },
            symbolStyle: {
                transparency: 0.5,
                width: 55,
                color: "green"
            }
        };
        chart.hoverStyle(hoverStyle);
    }
    //allow animation for Chart series
    chart.useAnimation(true);
}
//# sourceMappingURL=errorBar.js.map